==> 1.3.0.tar.gz: lib/src/dice_roller.dart <==
import 'dart:math';

import 'package:logging/logging.dart';

/// A dice roller for M dice of N sides
class DiceRoller {
  final Logger log = Logger("DiceRoller");
  Random _random;

  /// Constructs a dice roller (Random can be injected)
  DiceRoller([Random r]) {
    _random = r ?? Random.secure();
  }

  /// Roll ndice of nsides and return results as list.
  List<int> roll(int ndice, int nsides) {
    // nextInt is zero-inclusive, add 1 so it starts at 1 like dice
    var results = [for (int i = 0; i < ndice; i++) _random.nextInt(nsides) + 1];
    log.finest(() => "roll ${ndice}d$nsides => $results");
    return results;
  }

  /// return result of rolling given number of nsided dice.
  List<int> rollWithExplode(
      {int ndice, int nsides, bool explode = false, int explodeLimit = 1000}) {
    var results = <int>[];
    var numToRoll = ndice;

    var explodeCount = 0;
    while (numToRoll > 0 && explodeCount <= explodeLimit) {
      if (explodeCount > 0) {
        log.finest("explode $numToRoll !");
      }
      var localResults = roll(numToRoll, nsides);
      results.addAll(localResults);
      if (!explode) {
        break;
      }
      if (nsides == 1) {
        log.info("exploding 1-sided dice not allowed");
        break;
      }

      explodeCount++;
      numToRoll = localResults.where((v) => v == nsides).length;
    }

    log.finest(() => "roll ${ndice}d!$nsides => $results");
    return results;
  }

  static const _fudgeVals = [-1, -1, 0, 0, 1, 1];

  /// Roll N fudge dice, return results
  List<int> rollFudge(int ndice) {
    var results = [
      for (var i = 0; i < ndice; i++)
        _fudgeVals[_random.nextInt(_fudgeVals.length)]
    ];
    log.finest(() => "roll ${ndice}dF => $results");
    return results;
  }
}

==> 1.3.4.tar.gz: lib/src/dice_roller.dart <==
import 'dart:math';

import 'package:logging/logging.dart';

/// A dice roller for M dice of N sides
class DiceRoller {
  final Logger _log = Logger("DiceRoller");
  Random _random;

  /// Constructs a dice roller (Random can be injected)
  DiceRoller([Random r]) {
    _random = r ?? Random.secure();
  }

  /// Roll ndice of nsides and return results as list.
  List<int> roll(int ndice, int nsides) {
    // nextInt is zero-inclusive, add 1 so it starts at 1 like dice
    var results = [for (int i = 0; i < ndice; i++) _random.nextInt(nsides) + 1];
    _log.finest(() => "roll ${ndice}d$nsides => $results");
    return results;
  }

  /// return result of rolling given number of nsided dice.
  List<int> rollWithExplode(
      {int ndice, int nsides, bool explode = false, int explodeLimit = 1000}) {
    var results = <int>[];
    var numToRoll = ndice;

    var explodeCount = 0;
    while (numToRoll > 0 && explodeCount <= explodeLimit) {
      if (explodeCount > 0) {
        _log.finest("explode $numToRoll !");
      }
      var localResults = roll(numToRoll, nsides);
      results.addAll(localResults);
      if (!explode) {
        break;
      }
      if (nsides == 1) {
        _log.info("exploding 1-sided dice not allowed");
        break;
      }

      explodeCount++;
      numToRoll = localResults.where((v) => v == nsides).length;
    }

    _log.finest(() => "roll ${ndice}d!$nsides => $results");
    return results;
  }

  static const _fudgeVals = [-1, -1, 0, 0, 1, 1];

  /// Roll N fudge dice, return results
  List<int> rollFudge(int ndice) {
    var results = [
      for (var i = 0; i < ndice; i++)
        _fudgeVals[_random.nextInt(_fudgeVals.length)]
    ];
    _log.finest(() => "roll ${ndice}dF => $results");
    return results;
  }
}
